@@ -40,6 +40,7 @@ extern "C" {
 #define DEFAULT_PERIOD		1024u
 #define DEFAULT_RATE		48000u
 #define DEFAULT_CHANNELS	2u
+/* CHMAP defaults to true when using UCM */
 #define DEFAULT_USE_CHMAP	false
 
 #define MAX_HTIMESTAMP_ERROR	64
@@ -227,7 +228,7 @@ struct state {
 	unsigned int auto_link:1;
 	unsigned int linked:1;
 	unsigned int is_batch:1;
-	unsigned int force_position:1;
+	unsigned int force_rate:1;
 
 	uint64_t iec958_codecs;
 
