@@ -5,6 +5,8 @@
 #ifndef __GST_PIPEWIRE_SINK_H__
 #define __GST_PIPEWIRE_SINK_H__
 
+#include "gstpipewirestream.h"
+
 #include <gst/gst.h>
 #include <gst/base/gstbasesink.h>
 
@@ -14,22 +16,9 @@
 
 G_BEGIN_DECLS
 
-#define GST_TYPE_PIPEWIRE_SINK \
-  (gst_pipewire_sink_get_type())
-#define GST_PIPEWIRE_SINK(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_PIPEWIRE_SINK,GstPipeWireSink))
-#define GST_PIPEWIRE_SINK_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_PIPEWIRE_SINK,GstPipeWireSinkClass))
-#define GST_IS_PIPEWIRE_SINK(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_PIPEWIRE_SINK))
-#define GST_IS_PIPEWIRE_SINK_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_PIPEWIRE_SINK))
-#define GST_PIPEWIRE_SINK_CAST(obj) \
-  ((GstPipeWireSink *) (obj))
-
-typedef struct _GstPipeWireSink GstPipeWireSink;
-typedef struct _GstPipeWireSinkClass GstPipeWireSinkClass;
-
+#define GST_TYPE_PIPEWIRE_SINK (gst_pipewire_sink_get_type())
+#define GST_PIPEWIRE_SINK_CAST(obj) ((GstPipeWireSink *) (obj))
+G_DECLARE_FINAL_TYPE (GstPipeWireSink, gst_pipewire_sink, GST, PIPEWIRE_SINK, GstBaseSink)
 
 /**
  * GstPipeWireSinkMode:
@@ -57,32 +46,14 @@ struct _GstPipeWireSink {
   GstBaseSink element;
 
   /*< private >*/
-  gchar *path;
-  gchar *target_object;
-  gchar *client_name;
-  int fd;
+  GstPipeWireStream *stream;
 
   /* video state */
   gboolean negotiated;
 
-  GstPipeWireCore *core;
-  struct spa_hook core_listener;
-  GstStructure *client_properties;
-
-  struct pw_stream *stream;
-  struct spa_hook stream_listener;
-
-  GstStructure *stream_properties;
   GstPipeWireSinkMode mode;
-
-  GstPipeWirePool *pool;
 };
 
-struct _GstPipeWireSinkClass {
-  GstBaseSinkClass parent_class;
-};
-
-GType gst_pipewire_sink_get_type (void);
 GType gst_pipewire_sink_mode_get_type (void);
 
 G_END_DECLS
